==> guile-2.0.11-3-armv6h.pkg.tar.xz: usr/lib/guile/2.0/ccache/ice-9/rdelim.go <==
GOOF----LE-4-2.0o      ] g 4       h      ] g  guile	 	g  define-module*	 	 	g  ice-9	g  rdelim	 		g  filenameS	
f  ice-9/rdelim.scm	g  exportsS	g  	read-line	
g  
read-line!	g  read-delimited	g  read-delimited!	g  read-string	g  read-string!	g  %read-delimited!	g  
%read-line	g  
write-line	
 		g  set-current-module	 	 	g  %init-rdelim-builtins	g  current-input-port	f  
	g  eof-object?	g  trim	g  
string-length	g  peek	 g  split	!g  concat	"g  string-set!	#g  error	$f  unexpected handle-delim value: 	%g  make-string	&g  string-concatenate-reverse	'g  	substring	(g  
string-append	)g  string	*g  make-syntax-transformer	+* 	,* 	-g  	check-arg	.g  macro	/g  $sc-dispatch	0/ 	1/ 	2g  any	3g  each-any	423	524	625	7g  
syntax-object	8g  unless	9g  top	:9 	;g  ribcage	<g  dummy	=g  exp	>g  message	?g  arg	@<=>? 	Ag  m-J5lAH$h$@BQ$tzWbvsahjU-3548	BA9 	CB::: 	Df  l-J5lAH$h$@BQ$tzWbvsahjU-3553	Ef  l-J5lAH$h$@BQ$tzWbvsahjU-3554	Ff  l-J5lAH$h$@BQ$tzWbvsahjU-3555	Gf  l-J5lAH$h$@BQ$tzWbvsahjU-3556	HDEFG 	I;@CH 	J; 	Kg  x	LK 	MB 	Nf  l-J5lAH$h$@BQ$tzWbvsahjU-3550	ON 	P;LMO 	Q:IJP 	Rg  hygiene	SR 	T78QS 	U7#QS 	Vg  syntax-violation	WV 	XV 	Yf  -source expression failed to match any pattern	Zg  integer?	[g  exact?	\g  index?	]g  string?	^f  not a string	_f  	bad index	`f  start beyond end	af  end beyond string length	bg  	read-char	cf  	bad count	dg  min	eg  char?	fg  unread-charC 5     h0     ]4	
5 4 >  "  G   4i>   "  G    h`   $  - . , 3 #  4 5"  $  CC
$  45$  C""           g  string
		[ g  port		[ g  rv		"	[ g  
terminator		'	[ g  nchars		,	[  g  filenamef  ice-9/rdelim.scm
	%
		(	
		'	 	"	(	
	"	(		'	,		'	(		,	-		,	(		8	.		A	.		E	.		F	/		P	.	 		[  g  nameg  
read-line! C
R !"#$       h   :  - . , 3 	#  45 #  #  
#  	454 5$  45"  $  *
$  &  CC&  CC$  "  $  C$  4	>  "  G  C$  C
6     2      g  delims
	  g  buf	  g  port		  g  handle-delim		  g  start		  g  end		  g  rv		P  g  
terminator		U  g  nchars		Z   	g  filenamef  ice-9/rdelim.scm
	4
		5	 	!	5	D	3	6	)	<	7	
	F	9	6	G	9	$	H	9		P	7	
	P	7		U	=		U	7		Z	>		Z	7		b	?		c	@		n	?		r	?		u	A		z	A		~	B	% 	B	 	C	 	E	% 	E	 	F	 	I	 	K	 	K	( 	K	 	L	 	I	 	M	 	N	 	N	 $	 		  g  nameg  read-delimited! CR%&'!() #$   h     - . , 3 #  45 #  "  454 5		
$  "  i44
	55$  4	5$  C
456$  "  $  C$  C
64	5$  

$  &  CC"o"k4
	5
	"
	d"       g  delims
	 g  port	 g  handle-delim		 g  
substrings		' g  total-chars		' g  buf-size		' g  buf		. g  rv		A g  
terminator		F g  nchars			K g  	new-total	
	R g  joined		p   g  filenamef  ice-9/rdelim.scm
	Q
		Q	1	!	R	'	'	S		(	V		.	V		1	W		;	Y	8	<	Y	&	=	Y	!	A	W		A	V		F	[		F	V		K	\		K	V		R	]		R	V		Z	^		_	j		b	k		n	k		p	j		p	i		{	l	
	|	n	 	n	
 	p	' 	p	 	l	
 	r	 	s	 	s	 	^	 	d	
 	^	 	d	& 	d	 	e	 	e	 	f	 	a	 	a		c		a		S		S		S	 1		  g  nameg  read-delimited CR4,-.16TU        h   d   ] C      \       g  dummy
		 g  exp		 g  message			 g  arg			  			   CXY     h(      ]	4 5$  @ 6             g  x
		" g  tmp		"  g  filenamef  ice-9/rdelim.scm
	v
 		"  g  
macro-typeg  syntax-rulesg  patternsg  expg  messageg  argg  ...   C5-RZ[        h(      ]4 5$  4 5$   
CCC              g  n
		!  g  filenamef  ice-9/rdelim.scm
	z
		{		
	{			{			{			{	 		!  g  nameg  index? C\R]#^\_`ab" 
   h8    - . , 3 #  45 #  
#  	4 54 5$  "  4 >  "  G  45$  "  4>  "  G  45$  "  4>  "  G  $  "  4>  "  G  4 5$  "  4	>  "  G  "  H$  94
545$  C4 >  "  G  "C"       g  buf
	7 g  port	7 g  start		7 g  end		7 g  n	 / g  c	 )  g  filenamef  ice-9/rdelim.scm
	}
		~		)		&	2 	
	< 		E 		L 		U 	
	_ 		h 		o 		x 	
  	  	  	  	
  	  	  	  	  	
  	  	*  	  	  	  	  	  	  	 	
	 	 	# 	) 	. 	/ 	 &	7	  g  nameg  read-string!g  
documentationf NRead all of the characters out of PORT and write them to BUF.
Returns the number of characters read.

This function only reads out characters from PORT if it will be able to
write them to BUF.  That is to say, if BUF is smaller than the number of
available characters, then BUF will be filled, and characters will be
left in the port. CR\#c%d&' 
    h     -  . , 3  #  45  #  $  45"  $  "  4>  "  G  "  a4$  45"  54 5$  	"4	
56
	d"           g  port
	  g  count	  g  
substrings		T  g  total-chars		T  g  buf-size		T  g  buf		q  g  nchars		|  g  	new-total	    g  filenamef  ice-9/rdelim.scm
 
	 	'	( 	
	) 		4 		8 		A 	-	H 		T 		U 		] 		^ 	!	g 	/	i 	!	q 		q 		t 		| 	  	  	  	  	  	  	.  	  	  		  	  	  	  	  	 
	  g  nameg  read-stringg  
documentationf  Read all of the characters out of PORT and return them as a string.
If the COUNT argument is present, treat it as a limit to the number of
characters to read.  By default, there is no limit. CR !]e()f#$ h     -  . , 3  #  45  #  4 5$  C$  C$  )45$  45$  
4	56CC
$  &45$  4 >  "  G  "   C
6       g  port
	  g  handle-delim	  g  
line/delim		*  g  line		/  g  delim		4   g  filenamef  ice-9/rdelim.scm
 
	 	%	! 	"	$ 		* 		/ 		/ 		4 		4 		? 		X 		b 		c 	(	m 		r 	(	z 	  	  	  	  	  	  	 	 
	  g  nameg  	read-line CRC             g  m
		(  g  filenamef  ice-9/rdelim.scm		
	)	#
	%
5	4
	|	Q
	z
	}
 
( 
 
	*
   C6 

==> guile-2.0.11-4-armv6h.pkg.tar.xz: usr/lib/guile/2.0/ccache/ice-9/rdelim.go <==
GOOF----LE-4-2.0o      ] g 4       h      ] g  guile	 	g  define-module*	 	 	g  ice-9	g  rdelim	 		g  filenameS	
f  ice-9/rdelim.scm	g  exportsS	g  	read-line	
g  
read-line!	g  read-delimited	g  read-delimited!	g  read-string	g  read-string!	g  %read-delimited!	g  
%read-line	g  
write-line	
 		g  set-current-module	 	 	g  %init-rdelim-builtins	g  current-input-port	f  
	g  eof-object?	g  trim	g  
string-length	g  peek	 g  split	!g  concat	"g  string-set!	#g  error	$f  unexpected handle-delim value: 	%g  make-string	&g  string-concatenate-reverse	'g  	substring	(g  
string-append	)g  string	*g  make-syntax-transformer	+* 	,* 	-g  	check-arg	.g  macro	/g  $sc-dispatch	0/ 	1/ 	2g  any	3g  each-any	423	524	625	7g  
syntax-object	8g  unless	9g  top	:9 	;g  ribcage	<g  dummy	=g  exp	>g  message	?g  arg	@<=>? 	Ag  m-VjzLuUuu6A9jQ1gJVAvV3G-3548	BA9 	CB::: 	Df  l-VjzLuUuu6A9jQ1gJVAvV3G-3553	Ef  l-VjzLuUuu6A9jQ1gJVAvV3G-3554	Ff  l-VjzLuUuu6A9jQ1gJVAvV3G-3555	Gf  l-VjzLuUuu6A9jQ1gJVAvV3G-3556	HDEFG 	I;@CH 	J; 	Kg  x	LK 	MB 	Nf  l-VjzLuUuu6A9jQ1gJVAvV3G-3550	ON 	P;LMO 	Q:IJP 	Rg  hygiene	SR 	T78QS 	U7#QS 	Vg  syntax-violation	WV 	XV 	Yf  -source expression failed to match any pattern	Zg  integer?	[g  exact?	\g  index?	]g  string?	^f  not a string	_f  	bad index	`f  start beyond end	af  end beyond string length	bg  	read-char	cf  	bad count	dg  min	eg  char?	fg  unread-charC 5     h0     ]4	
5 4 >  "  G   4i>   "  G    h`   $  - . , 3 #  4 5"  $  CC
$  45$  C""           g  string
		[ g  port		[ g  rv		"	[ g  
terminator		'	[ g  nchars		,	[  g  filenamef  ice-9/rdelim.scm
	%
		(	
		'	 	"	(	
	"	(		'	,		'	(		,	-		,	(		8	.		A	.		E	.		F	/		P	.	 		[  g  nameg  
read-line! C
R !"#$       h   :  - . , 3 	#  45 #  #  
#  	454 5$  45"  $  *
$  &  CC&  CC$  "  $  C$  4	>  "  G  C$  C
6     2      g  delims
	  g  buf	  g  port		  g  handle-delim		  g  start		  g  end		  g  rv		P  g  
terminator		U  g  nchars		Z   	g  filenamef  ice-9/rdelim.scm
	4
		5	 	!	5	D	3	6	)	<	7	
	F	9	6	G	9	$	H	9		P	7	
	P	7		U	=		U	7		Z	>		Z	7		b	?		c	@		n	?		r	?		u	A		z	A		~	B	% 	B	 	C	 	E	% 	E	 	F	 	I	 	K	 	K	( 	K	 	L	 	I	 	M	 	N	 	N	 $	 		  g  nameg  read-delimited! CR%&'!() #$   h     - . , 3 #  45 #  "  454 5		
$  "  i44
	55$  4	5$  C
456$  "  $  C$  C
64	5$  

$  &  CC"o"k4
	5
	"
	d"       g  delims
	 g  port	 g  handle-delim		 g  
substrings		' g  total-chars		' g  buf-size		' g  buf		. g  rv		A g  
terminator		F g  nchars			K g  	new-total	
	R g  joined		p   g  filenamef  ice-9/rdelim.scm
	Q
		Q	1	!	R	'	'	S		(	V		.	V		1	W		;	Y	8	<	Y	&	=	Y	!	A	W		A	V		F	[		F	V		K	\		K	V		R	]		R	V		Z	^		_	j		b	k		n	k		p	j		p	i		{	l	
	|	n	 	n	
 	p	' 	p	 	l	
 	r	 	s	 	s	 	^	 	d	
 	^	 	d	& 	d	 	e	 	e	 	f	 	a	 	a		c		a		S		S		S	 1		  g  nameg  read-delimited CR4,-.16TU        h   d   ] C      \       g  dummy
		 g  exp		 g  message			 g  arg			  			   CXY     h(      ]	4 5$  @ 6             g  x
		" g  tmp		"  g  filenamef  ice-9/rdelim.scm
	v
 		"  g  
macro-typeg  syntax-rulesg  patternsg  expg  messageg  argg  ...   C5-RZ[        h(      ]4 5$  4 5$   
CCC              g  n
		!  g  filenamef  ice-9/rdelim.scm
	z
		{		
	{			{			{			{	 		!  g  nameg  index? C\R]#^\_`ab" 
   h8    - . , 3 #  45 #  
#  	4 54 5$  "  4 >  "  G  45$  "  4>  "  G  45$  "  4>  "  G  $  "  4>  "  G  4 5$  "  4	>  "  G  "  H$  94
545$  C4 >  "  G  "C"       g  buf
	7 g  port	7 g  start		7 g  end		7 g  n	 / g  c	 )  g  filenamef  ice-9/rdelim.scm
	}
		~		)		&	2 	
	< 		E 		L 		U 	
	_ 		h 		o 		x 	
  	  	  	  	
  	  	  	  	  	
  	  	*  	  	  	  	  	  	  	 	
	 	 	# 	) 	. 	/ 	 &	7	  g  nameg  read-string!g  
documentationf NRead all of the characters out of PORT and write them to BUF.
Returns the number of characters read.

This function only reads out characters from PORT if it will be able to
write them to BUF.  That is to say, if BUF is smaller than the number of
available characters, then BUF will be filled, and characters will be
left in the port. CR\#c%d&' 
    h     -  . , 3  #  45  #  $  45"  $  "  4>  "  G  "  a4$  45"  54 5$  	"4	
56
	d"           g  port
	  g  count	  g  
substrings		T  g  total-chars		T  g  buf-size		T  g  buf		q  g  nchars		|  g  	new-total	    g  filenamef  ice-9/rdelim.scm
 
	 	'	( 	
	) 		4 		8 		A 	-	H 		T 		U 		] 		^ 	!	g 	/	i 	!	q 		q 		t 		| 	  	  	  	  	  	  	.  	  	  		  	  	  	  	  	 
	  g  nameg  read-stringg  
documentationf  Read all of the characters out of PORT and return them as a string.
If the COUNT argument is present, treat it as a limit to the number of
characters to read.  By default, there is no limit. CR !]e()f#$ h     -  . , 3  #  45  #  4 5$  C$  C$  )45$  45$  
4	56CC
$  &45$  4 >  "  G  "   C
6       g  port
	  g  handle-delim	  g  
line/delim		*  g  line		/  g  delim		4   g  filenamef  ice-9/rdelim.scm
 
	 	%	! 	"	$ 		* 		/ 		/ 		4 		4 		? 		X 		b 		c 	(	m 		r 	(	z 	  	  	  	  	  	  	 	 
	  g  nameg  	read-line CRC             g  m
		(  g  filenamef  ice-9/rdelim.scm		
	)	#
	%
5	4
	|	Q
	z
	}
 
( 
 
	*
   C6 
